==> haskell-dlist-0.8.0.3-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dlist
version: 0.8.0.3
id: dlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ
key: dlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ
license: BSD3
copyright: 2006-2009 Don Stewart, 2013-2016 Sean Leather
maintainer: Sean Leather <sean.leather@gmail.com>
homepage: https://github.com/spl/dlist
synopsis: Difference lists
description:
    Difference lists are a list-like type supporting O(1) append. This is
    particularly useful for efficient logging and pretty printing (e.g. with the
    Writer monad), where list append quickly becomes too expensive.
category: Data
author: Don Stewart
exposed: True
indefinite: False
exposed-modules:
    Data.DList
abi: b107514e173207d2f3e9b5aba950dc0f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/dlist-0.8.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/dlist-0.8.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/dlist-0.8.0.3
hs-libraries: HSdlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
haddock-interfaces: /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html: /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dlist-0.8.0.4-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dlist
version: 0.8.0.4
id: dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
key: dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
license: BSD3
copyright: 2006-2009 Don Stewart, 2013-2016 Sean Leather
maintainer: Sean Leather <sean.leather@gmail.com>
homepage: https://github.com/spl/dlist
synopsis: Difference lists
description:
    Difference lists are a list-like type supporting O(1) append. This is
    particularly useful for efficient logging and pretty printing (e.g. with the
    Writer monad), where list append quickly becomes too expensive.
category: Data
author: Don Stewart
exposed: True
indefinite: False
exposed-modules:
    Data.DList
abi: b98e175ed6b9bea3c0e69ce59165f686
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/dlist-0.8.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/dlist-0.8.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/dlist-0.8.0.4
hs-libraries: HSdlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
haddock-interfaces: /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html: /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
